"""DNScheck constants."""

from enum import StrEnum, unique


@unique
class NssetCheckStatus(StrEnum):
    """Nsset check status.

    Attributes:
        STARTED: Nsset check has been started. Domain checks were created.
        EVALUATED: Nsset check results have been evaluated. This value is deprecated
            and will be removed in the next version.
        FINISHED: Nsset check is finished. If the check failed, notifications
            have been sent.
    """

    STARTED = "started"
    EVALUATED = "evaluated"  # This value is deprecated and will be removed in the next version.
    FINISHED = "finished"


@unique
class DomainCheckStatus(StrEnum):
    """Domain check status."""

    CREATED = "created"
    STARTED = "started"
    FINISHED = "finished"


@unique
class NssetCheckProfile(StrEnum):
    """Nsset check profile."""

    DEFAULT = "default"


@unique
class TestResultLevel(StrEnum):
    """Test result level.

    https://doc.zonemaster.fr/latest/specifications/tests/SeverityLevelDefinitions.html
    """

    CRITICAL = "CRITICAL"
    ERROR = "ERROR"
    WARNING = "WARNING"
    NOTICE = "NOTICE"
    INFO = "INFO"


CHECK_LEVEL_MAP = {
    0: (),
    1: (TestResultLevel.CRITICAL,),
    2: (TestResultLevel.CRITICAL, TestResultLevel.ERROR),
    3: (TestResultLevel.CRITICAL, TestResultLevel.ERROR, TestResultLevel.WARNING),
    4: (TestResultLevel.CRITICAL, TestResultLevel.ERROR, TestResultLevel.WARNING, TestResultLevel.NOTICE),
}


@unique
class EmailType(StrEnum):
    """Email type enum."""

    DNSCHECK = "dnscheck"


@unique
class MessageTemplate(StrEnum):
    """Message template."""

    DNSCHECK_SUBJECT = "dnscheck-subject.txt"
    DNSCHECK_BODY = "dnscheck-body.txt"


@unique
class ReferenceType(StrEnum):
    """Message reference type."""

    CONTACT = "contact"
    NSSET = "nsset"
