"""Run Alembic migrations."""

import alembic_postgresql_enum  # noqa: F401
from alembic import context
from sqlalchemy.engine import Connection

from dnscheck.db.common import Base, get_engine
from dnscheck.settings import APP

target_metadata = Base.metadata


if not APP.is_loaded:
    APP.load()


def run_migrations(connection: Connection) -> None:
    """Actually run migrations."""
    context.configure(
        connection=connection,
        target_metadata=target_metadata,
        # Use batch mode for SQLite ALTERs.
        # See https://alembic.sqlalchemy.org/en/latest/batch.html#batch-mode-with-autogenerate
        render_as_batch=True,
        # Required for enum updates in postgresql.
        transaction_per_migration=True,
    )

    context.run_migrations()


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    connectable = get_engine()

    with connectable.connect() as connection:
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            literal_binds=True,
            dialect_opts={"paramstyle": "named"},
            version_table_schema=APP.settings.db_schema,
        )

        with context.begin_transaction():
            context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = get_engine()

    with connectable.connect() as connection:
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            version_table_schema=APP.settings.db_schema,
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
