"""Initial migration.

Revision ID: 1c48f73339e2
Revises:
Create Date: 2024-08-19 12:38:54.206902+00:00

"""

from collections.abc import Sequence

import sqlalchemy as sa
import sqlalchemy_utc
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "1c48f73339e2"
down_revision: str | None = None
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade() -> None:
    sa.Enum("CREATED", "STARTED", "FINISHED", name="domaincheckstatus").create(op.get_bind())
    sa.Enum("FAIL", "SUCCESS", name="nssetcheckresult").create(op.get_bind())
    sa.Enum("STARTED", "CHECKED", "EVALUATED", "FINISHED", name="nssetcheckstatus").create(op.get_bind())
    sa.Enum("DEFAULT", name="nssetcheckprofile").create(op.get_bind())
    op.create_table(
        "dnscheck_nsset",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("nsset_id", sa.String(), nullable=False),
        sa.Column("handle", sa.String(), nullable=False),
        sa.Column(
            "last_synced",
            sqlalchemy_utc.sqltypes.UtcDateTime(timezone=True),
            server_default=sqlalchemy_utc.utcnow(),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(op.f("ix_dnscheck_nsset_nsset_id"), "dnscheck_nsset", ["nsset_id"], unique=True)
    op.create_table(
        "dnscheck_nsset_check",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("nsset_id", sa.String(), nullable=False),
        sa.Column("nsset_history_id", sa.String(), nullable=False),
        sa.Column("handle", sa.String(), nullable=False),
        sa.Column("nameservers", sa.JSON(), nullable=False),
        sa.Column("profile", postgresql.ENUM("DEFAULT", name="nssetcheckprofile", create_type=False), nullable=False),
        sa.Column(
            "status",
            postgresql.ENUM("STARTED", "CHECKED", "EVALUATED", "FINISHED", name="nssetcheckstatus", create_type=False),
            nullable=False,
        ),
        sa.Column(
            "result", postgresql.ENUM("FAIL", "SUCCESS", name="nssetcheckresult", create_type=False), nullable=True
        ),
        sa.Column(
            "started_at",
            sqlalchemy_utc.sqltypes.UtcDateTime(timezone=True),
            server_default=sqlalchemy_utc.utcnow(),
            nullable=False,
        ),
        sa.Column("finished_at", sqlalchemy_utc.sqltypes.UtcDateTime(timezone=True), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        op.f("ix_dnscheck_nsset_check_nsset_history_id"), "dnscheck_nsset_check", ["nsset_history_id"], unique=False
    )
    op.create_index(op.f("ix_dnscheck_nsset_check_nsset_id"), "dnscheck_nsset_check", ["nsset_id"], unique=False)
    op.create_table(
        "dnscheck_domain_check",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("nsset_check_id", sa.Integer(), nullable=False),
        sa.Column("domain", sa.String(), nullable=False),
        sa.Column("test_id", sa.String(), nullable=True),
        sa.Column(
            "status",
            postgresql.ENUM("CREATED", "STARTED", "FINISHED", name="domaincheckstatus", create_type=False),
            nullable=False,
        ),
        sa.Column("started_at", sqlalchemy_utc.sqltypes.UtcDateTime(timezone=True), nullable=True),
        sa.Column("finished_at", sqlalchemy_utc.sqltypes.UtcDateTime(timezone=True), nullable=True),
        sa.Column("results", sa.JSON(), nullable=True),
        sa.Column("summary", sa.JSON(), nullable=True),
        sa.ForeignKeyConstraint(
            ["nsset_check_id"],
            ["dnscheck_nsset_check.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )


def downgrade() -> None:
    op.drop_table("dnscheck_domain_check")
    op.drop_index(op.f("ix_dnscheck_nsset_check_nsset_id"), table_name="dnscheck_nsset_check")
    op.drop_index(op.f("ix_dnscheck_nsset_check_nsset_history_id"), table_name="dnscheck_nsset_check")
    op.drop_table("dnscheck_nsset_check")
    op.drop_index(op.f("ix_dnscheck_nsset_nsset_id"), table_name="dnscheck_nsset")
    op.drop_table("dnscheck_nsset")
    sa.Enum("DEFAULT", name="nssetcheckprofile").drop(op.get_bind())
    sa.Enum("STARTED", "CHECKED", "EVALUATED", "FINISHED", name="nssetcheckstatus").drop(op.get_bind())
    sa.Enum("FAIL", "SUCCESS", name="nssetcheckresult").drop(op.get_bind())
    sa.Enum("CREATED", "STARTED", "FINISHED", name="domaincheckstatus").drop(op.get_bind())
