"""DNScheck pydantic models."""

from pydantic import BaseModel, NonNegativeInt
from regal import DSRecord


class Nameserver(BaseModel):
    """Nameserver model."""

    fqdn: str
    ip_addresses: list[str] = []


class DSInfo(BaseModel):
    """DS info."""

    algorithm: NonNegativeInt
    digest: str
    digtype: NonNegativeInt
    keytag: NonNegativeInt

    @classmethod
    def from_ds_record(cls, ds_record: DSRecord) -> "DSInfo":
        """Create DSInfo from DSRecord."""
        return cls(
            algorithm=ds_record.alg,
            digest=ds_record.digest,
            digtype=ds_record.digest_type,
            keytag=ds_record.keytag,
        )
