from threading import Event

import pytest
from testfixtures import LogCapture

from dnscheck.utils import StopProcess, async_to_sync, defer_errors, run_unless_stopped


def test_async_to_sync_synchronous_context():
    async def func(x: int) -> int:
        return x

    assert async_to_sync(func)(42) == 42


def _ident(v):
    return v


def test_run_unless_stopped_not_set():
    stop_event = Event()

    assert run_unless_stopped(_ident, stop_event=stop_event)(42) == 42


def test_run_unless_stopped_set():
    stop_event = Event()
    stop_event.set()

    with pytest.raises(StopProcess):
        run_unless_stopped(_ident, stop_event=stop_event)(42)


def test_defer_errors_ok():
    with LogCapture() as logs:
        assert defer_errors(_ident)(42) == 42

    logs.check()


def test_defer_errors_error():
    with LogCapture() as logs:
        assert defer_errors(lambda: 0 / 0)() is None

    logs.check(
        ("dnscheck.utils", "ERROR", "Unexpected error: ZeroDivisionError('division by zero')"),
    )
